{% load i18n %}

<option value="">{% translate "None, just format it for me" %}</option>
<option value="" disabled></option>

<optgroup label="Configured ping channels">
    {% for webhook in webhooks %}
        <option value="{{ webhook.pk }}">{{ webhook.name }}</option>
    {% endfor %}
</optgroup>
