{% load fleetpings_urls %}

{% if doctrines|length > 0 %}
    <datalist id="fleetDoctrineList">
        {% for doctrine in doctrines %}
            {% if use_fleet_doctrines %}
                <option value="{{ doctrine.name }}" data-doctrine-url="{% fleetpings_reverse_url 'fittings:view_doctrine' doctrine.pk %}">
            {% else %}
                <option value="{{ doctrine.name }}" data-doctrine-url="{{ doctrine.link }}">
            {% endif %}
        {% endfor %}
    </datalist>
{% endif %}
