{% extends "allianceauth/base.html" %}

{% load i18n %}

{% block page_title %}{% translate "Fleet Ping Tool" %}{% endblock %}

{% block content %}
    {% translate "Fleet Ping Tool" as translated_header %}
    {% include "fleetpings/partials/header/page-header.html" with header_text=translated_header %}

    {% block details %}{% endblock %}
{% endblock %}
